[or-cvs] fix an assert -- we"re not allowed to write onto a conn aft...

Roger Dingledine arma at seul.org
Wed Mar 23 23:19:20 UTC 2005


Update of /home2/or/cvsroot/tor/src/or
In directory moria.mit.edu:/home2/arma/work/onion/cvs/tor/src/or

Modified Files:
	connection.c 
Log Message:
fix an assert -- we're not allowed to write onto a conn after we've
connection_unregistered it. there's still more work to be done here,
since we need to make sure to send back the socks-reply as soon as we
know what it will be -- we can't just wait until connection-about-to-close
to deal with it.


Index: connection.c
===================================================================
RCS file: /home2/or/cvsroot/tor/src/or/connection.c,v
retrieving revision 1.342
retrieving revision 1.343
diff -u -d -r1.342 -r1.343
--- connection.c	23 Mar 2005 22:11:59 -0000	1.342
+++ connection.c	23 Mar 2005 23:19:18 -0000	1.343
@@ -279,11 +279,9 @@
       break;
     case CONN_TYPE_AP:
       if (conn->socks_request->has_finished == 0) {
-        log_fn(LOG_INFO,"Cleaning up AP -- sending socks reject.");
-        conn->hold_open_until_flushed = 1;
-        /* XXX this socks_reply never gets sent, since conn
-         * gets removed right after this function finishes. */
-        connection_ap_handshake_socks_reply(conn, NULL, 0, SOCKS5_GENERAL_ERROR);
+        /* since conn gets removed right after this function finishes,
+         * there's no point trying to send back a reply at this point. */
+        log_fn(LOG_INFO,"Bug: Closing stream without sending back a socks reply.");
       } else {
         control_event_stream_status(conn, STREAM_EVENT_CLOSED);
       }



More information about the tor-commits mailing list